## SAFE Encoder-Decoder 

::: safe.converter
    options:
        members:
            - encode
            - decode
            - SAFEConverter
        show_root_heading: false


---

## SAFE Tokenizer

::: safe.tokenizer
    options:
        members:
            - SAFESplitter
            - SAFETokenizer
        show_root_heading: false



---

## Utils

::: safe.utils